function [Q] = calQm(qua)
% Author: Yang Qi, Department of Biochemistry and Department of Computer
%         Science, Duke University
%
% convert a quaternion to its corresponding Q matrix
% input: a 1x4 quaternion qua
% output: a 5x5 Q matrix

q1 = qua(1);
q2 = qua(2);
q3 = qua(3);
q4 = qua(4);

[x1,y1,z1] = deal(q1^2+q2^2-q3^2-q4^2, 2*q2*q3-2*q1*q4, 2*q2*q4+2*q1*q3);
[x2,y2,z2] = deal(2*q2*q3+2*q1*q4, q1^2-q2^2+q3^2-q4^2, 2*q3*q4-2*q1*q2);
[x3,y3,z3] = deal(2*q2*q4-2*q1*q3, 2*q3*q4+2*q1*q2, q1^2-q2^2-q3^2+q4^2);

Q = [x1^2-x3^2,x2^2-x3^2,2*x1*x2,2*x1*x3,2*x2*x3;
     y1^2-y3^2,y2^2-y3^2,2*y1*y2,2*y1*y3,2*y2*y3;
     x1*y1-x3*y3,x2*y2-x3*y3,x1*y2+x2*y1,x1*y3+x3*y1,x2*y3+x3*y2;
     x1*z1-x3*z3,x2*z2-x3*z3,x1*z2+x2*z1,x1*z3+x3*z1,x2*z3+x3*z2;
     y1*z1-y3*z3,y2*z2-y3*z3,y1*z2+y2*z1,y1*z3+y3*z1,y2*z3+y3*z2];
end