function [ws] = calws(s1,quaR,Qave)
% Author: Yang Qi, Department of Biochemistry and Department of Computer
%         Science, Duke University
%
% calcalute the eigen values of transformed Saupe tensors
% the transformation includs the first right rotation and the averaging
% input: a 5xNs matrix containing vectorized Saupe tensors s1, quaternion 
%        of the right rotation quaR, the averaging Q matrix Qave
%        quaR is NOT the same quaR in the output!
% output: a Nsx3 matrix containing Ns sets of eigen values
% requires calQm, v2m

QR = calQm(quaR);

s1q = Qave*QR*s1;
s1qm = v2m(s1q);

Ns = size(s1,2);
ws = zeros(Ns,3);

for i = 1:Ns
    [u,w,v] = svd(s1qm(:,:,i));
    
    for j = 1:3
        w(j,j) = u(:,j)'*v(:,j)*w(j,j);
    end
    
    ws(i,:) = [w(1,1),w(2,2),w(3,3)];
end
end