function [Das] = s2da(s)
% Author: Yang Qi, Department of Biochemistry and Department of Computer
%         Science, Duke University
%
% calculate the largest eigen value of a Saupe tensor
% input: a 5xNs matrix containing vectorized Saupe tensors s
% output: a Ns-element row vector containing the largest eigen values
% requires v2m

sm = v2m(s);
Ns = size(s,2);
Das = zeros(1,Ns);

for i = 1:Ns
    [u,w,v] = svd(sm(:,:,i));
    for j = 1:3
        w(j,j) = u(:,j)'*v(:,j)*w(j,j);
    end
    ws = [w(1,1),w(2,2),w(3,3)];
    
    [~, idx] = max(abs(ws));
    
    Das(i) = ws(idx);
end
end